This directory contains example notebooks explaining how to use the RAIL Estimation Module.

- [nzdir_as_pipeline](https://lsstdescrail.readthedocs.io/en/latest/source/estimation-notebooks.html#the-nzdir-estimator) provides a quick demo of the NZDir estimator.

- **RAIL_estimation_demo.ipynb** explains to inform a model used for photo-z estimation, and then how to use that model to estimate p(z).

- **SimpleSOM_demo.ipynb**, **somocluSOM_demo.ipynb**, and **somocluSOMcluster_demo.ipynb** demonstrate of the use of the `MiniSOMSummarizer` summarization module.

- [test_sampled_summarizers.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/estimation-notebooks.html#testing-sampled-summarizers) outlines quick and dirty bootstrap versions of the `NaiveStackSummarizer`, `PointEstHistSummarizer`, and `VarInference` sumarizers, as well as `NZDirSummarizer`.
